summaryrefslogtreecommitdiffstats
path: root/kmail/kmkernel.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:37:21 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:37:21 -0600
commit86d8364ac704bdc8ad2dfcf52307d9626cfac567 (patch)
tree97d3ac2c2f60780d9a1de4f82caac7cb27534501 /kmail/kmkernel.h
parenta9bde819f2b421dcc44741156e75eca4bb5fb4f4 (diff)
downloadtdepim-86d8364ac704bdc8ad2dfcf52307d9626cfac567.tar.gz
tdepim-86d8364ac704bdc8ad2dfcf52307d9626cfac567.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'kmail/kmkernel.h')
-rw-r--r--kmail/kmkernel.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kmail/kmkernel.h b/kmail/kmkernel.h
index 471a7740..fb01231b 100644
--- a/kmail/kmkernel.h
+++ b/kmail/kmkernel.h
@@ -21,7 +21,7 @@
#define kmkernel KMKernel::self()
#define kmconfig KMKernel::config()
-namespace KIO {
+namespace TDEIO {
class Job;
}
namespace KWallet {
@@ -249,7 +249,7 @@ public:
/** normal control stuff */
static KMKernel *self() { return mySelf; }
- static KConfig *config();
+ static TDEConfig *config();
void init();
void readConfig();
@@ -257,7 +257,7 @@ public:
void recreateCorruptIndexFiles();
void testDir(const char *_name);
void recoverDeadLetters();
- void initFolders(KConfig* cfg);
+ void initFolders(TDEConfig* cfg);
void closeAllKMailWindows();
void cleanup(void);
void quit();
@@ -416,7 +416,7 @@ public slots:
/// Save contents of all open composer widnows to ~/dead.letter
void dumpDeadLetters();
/** Call this slot instead of directly KConfig::sync() to
minimize the overall config writes. Calling this slot will
schedule a sync of the application config file using a timer, so
that many consecutive calls can be condensed into a single
@@ -432,8 +432,8 @@ public slots:
void slotConfigChanged();
protected slots:
- void slotDataReq(KIO::Job*,TQByteArray&);
- void slotResult(KIO::Job*);
+ void slotDataReq(TDEIO::Job*,TQByteArray&);
+ void slotResult(TDEIO::Job*);
signals:
void configChanged();
@@ -470,7 +470,7 @@ private:
TQByteArray data;
int offset;
};
- TQMap<KIO::Job *, putData> mPutJobs;
+ TQMap<TDEIO::Job *, putData> mPutJobs;
/** previous KMail version. If different from current,
the user has just updated. read from config */
TQString the_previousVersion;
@@ -416,7 +416,7 @@ public slots:
/// Save contents of all open composer widnows to ~/dead.letter
void dumpDeadLetters();
- /** Call this slot instead of directly KConfig::sync() to
+ /** Call this slot instead of directly TDEConfig::sync() to
minimize the overall config writes. Calling this slot will
schedule a sync of the application config file using a timer, so